--[[ attacherScale 

Author: 		HoFFi (modding-welt.com)
Remarks:		


Description: 	script for attacherScale

Version: 		1.0.0.0

Changelog: 		2021-05-14 	- initial release


--------------------------------------------------------------------------------------------------


]]


attacherScale = {};

attacherScale.modDir = g_currentModDirectory;
attacherScale.currentModName = g_currentModName;

function attacherScale.prerequisitesPresent(specializations)
    return true; 
end;

function attacherScale.registerEventListeners(vehicleType)
	for _, spec in pairs({"onLoad", "onUpdate", "onDraw", "onRegisterActionEvents", "actionEventTPSCALE_TARE"}) do
		SpecializationUtil.registerEventListener(vehicleType, spec, attacherScale)
	end
end

function attacherScale.registerFunctions(vehicleType)
    SpecializationUtil.registerFunction(vehicleType, "actionEventTPSCALE_TARE", attacherScale.actionEventTPSCALE_TARE)
end

function attacherScale:onLoad(savegame)
	self.attacherScale = {}
	self.actionEvents = {}
	self.attacherScale.totalMass1 = 0
	self.attacherScale.tare = 0
	self.MassToDisplay = 0
	self.oneDecal = I3DUtil.indexToObject(self.components, "oneDecal", self.i3dMappings);
	self.tenDecal = I3DUtil.indexToObject(self.components, "tenDecal", self.i3dMappings);
	self.hunDecal = I3DUtil.indexToObject(self.components, "hunDecal", self.i3dMappings);
	self.thoDecal = I3DUtil.indexToObject(self.components, "thoDecal", self.i3dMappings);
end;

function attacherScale:onRegisterActionEvents(isActiveForInput, isActiveForInputIgnoreSelection)
    -- print("ToDi_Attachment:onRegisterActionEvents")
	if self.isClient then
		local spec = self.spec_attacherJoints
		self:clearActionEventsTable(spec.actionEvents)
		if isActiveForInputIgnoreSelection then
			local actionEventId
			_, actionEventId = self:addActionEvent(spec.actionEvents, InputAction.TPSCALE_TARE, self, attacherScale.actionEventTPSCALE_TARE, false, true, false, true, nil)
			g_inputBinding:setActionEventTextPriority(actionEventId, GS_PRIO_LOW)
        end
	end
end

function attacherScale:onUpdate(dt)
	if self.isClient then	
		local spec = self.spec_attacherJoints
		local actionEvent = spec.actionEvents[InputAction.TPSCALE_TARE]
	
		self.attacherScale.totalMass1 = self:getTotalMass(onlyGivenVehicle) - 0.150
		 
		self.MassToDisplay = (self.attacherScale.totalMass1 * 1000) - (self.attacherScale.tare * 1000)
		
		if self.oneDecal ~= nil then
			a = math.floor(self.MassToDisplay / 1000)
			z = math.floor((self.MassToDisplay - (a * 1000)) / 100)
			y = math.floor((self.MassToDisplay - ((a * 1000) + (z * 100))) / 10)
			x = math.floor(self.MassToDisplay - ((a * 1000) + (z * 100) + (y * 10)))
		end
		
		setShaderParameter(self.oneDecal, "number", tonumber(x), 0, 0, 0, false)
		setShaderParameter(self.tenDecal, "number", tonumber(y), 0, 0, 0, false)
		setShaderParameter(self.hunDecal, "number", tonumber(z), 0, 0, 0, false)
		setShaderParameter(self.thoDecal, "number", tonumber(a), 0, 0, 0, false)
	end;
end;

function attacherScale.actionEventTPSCALE_TARE(self, actionName, inputValue, callbackState, isAnalog)
	self.attacherScale.tare = self.attacherScale.totalMass1
end

function attacherScale:onDraw(isActiveForInput)
	if self.isClient then
		if isActiveForInput then
			--if self.attacherScale.showInHud then
				text1 = MathUtil.round((self.attacherScale.totalMass1 * 1000), 2)
				text2 = MathUtil.round(((self.attacherScale.totalMass1 * 1000) - (self.attacherScale.tare * 1000)), 2)
				if text2 ~= text1 then
					g_currentMission:addExtraPrintText(g_i18n:getText("typeDesc_weight") ..": " .. text1 .. g_i18n:getText("unit_kg") .. " | TARE: " .. text2 .. g_i18n:getText("unit_kg"))
				else
					g_currentMission:addExtraPrintText(g_i18n:getText("typeDesc_weight") ..": " .. text1 .. g_i18n:getText("unit_kg"))
				end
			--end
		end
	end
end